# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bixo/holiday/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bixo/holiday/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bixo\\Holiday\\": "packages/bixo/holiday/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bixo\Holiday\Providers\HolidayServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Holiday'  => Bixo\Holiday\Facades\Holiday::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bixo\\HolidayTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bixo\Holiday\Providers\HolidayServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bixo\Holiday\Providers\HolidayServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bixo\Holiday\Providers\HolidayServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/holiday/{modulename}

**User**

    http://path-to-route-folder/user/holiday/{modulename}

**Public**

    http://path-to-route-folder/holidays


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/holiday/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/holiday/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/holiday/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/holiday/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/holiday/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/holiday/{modulename}/{slug}
    METHOD: GET