<?php

namespace Bixo\Holiday\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Holiday\Http\Requests\HolidayRequest;
use Bixo\Holiday\Interfaces\HolidayRepositoryInterface;
use Bixo\Holiday\Models\Holiday;
use Bixo\Holiday\Forms\Holiday as Form;

/**
 * APIController  class for holiday.
 */
class HolidayAPIController extends BaseController
{

    /**
     * Initialize holiday resource controller.
     *
     * @param type HolidayRepositoryInterface $holiday
     *
     * @return null
     */
    public function __construct(HolidayRepositoryInterface $holiday)
    {
        parent::__construct();
        $this->repository = $holiday;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Holiday\Repositories\Criteria\HolidayResourceCriteria::class);
    }

    /**
     * Display a list of holiday.
     *
     * @return Response
     */
    public function index(HolidayRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Holiday\Repositories\Presenter\HolidayPresenter::class)
            ->paginate();
    }

    /**
     * Display holiday.
     *
     * @param Request $request
     * @param Model   $holiday
     *
     * @return Response
     */
    public function show(HolidayRequest $request, Holiday $holiday)
    {
        return $holiday->setPresenter(\Bixo\Holiday\Repositories\Presenter\HolidayListPresenter::class);
        ;
    }

    /**
     * Create new holiday.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(HolidayRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('holiday::holiday.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('holiday/holiday/' . $holiday->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('holiday/holiday');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the holiday.
     *
     * @param Request $request
     * @param Model   $holiday
     *
     * @return Response
     */
    public function update(HolidayRequest $request, Holiday $holiday)
    {
        try {
            $data = $request->all();

            $holiday->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('holiday::holiday.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('holiday/holiday/' . $holiday->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('holiday/holiday/' . $holiday->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the holiday.
     *
     * @param Model   $holiday
     *
     * @return Response
     */
    public function destroy(HolidayRequest $request, Holiday $holiday)
    {
        try {
            $holiday->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('holiday::holiday.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('holiday/holiday/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('holiday/holiday/' . $holiday->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
